==> truth-proto-extension-1.1.3-sources.jar: com/google/common/truth/extensions/proto/AutoValue_DiffResult_RepeatedField_PairResult.java <==
package com.google.common.truth.extensions.proto;

import com.google.common.base.Optional;
import com.google.errorprone.annotations.concurrent.LazyInit;
import com.google.protobuf.Descriptors;
import java.lang.Integer;
import java.lang.Iterable;
import java.lang.Object;
import java.lang.Override;
import java.lang.SuppressWarnings;

final class AutoValue_DiffResult_RepeatedField_PairResult extends $AutoValue_DiffResult_RepeatedField_PairResult {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile Iterable<? extends RecursableDiffEntity> childEntities;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile boolean isMessage;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile boolean isMessage$Memoized;

  AutoValue_DiffResult_RepeatedField_PairResult(RecursableDiffEntity.WithResultCode.Result result$,
      Descriptors.FieldDescriptor fieldDescriptor$, Optional<Integer> actualFieldIndex$,
      Optional<Integer> expectedFieldIndex$, Optional<Object> actual$, Optional<Object> expected$,
      Optional<DiffResult> breakdown$) {
    super(result$, fieldDescriptor$, actualFieldIndex$, expectedFieldIndex$, actual$, expected$, breakdown$);
  }

  @Override
  Iterable<? extends RecursableDiffEntity> childEntities() {
    if (childEntities == null) {
      synchronized (this) {
        if (childEntities == null) {
          childEntities = super.childEntities();
          if (childEntities == null) {
            throw new NullPointerException("childEntities() cannot return null");
          }
        }
      }
    }
    return childEntities;
  }

  @Override
  boolean isMessage() {
    if (!isMessage$Memoized) {
      synchronized (this) {
        if (!isMessage$Memoized) {
          isMessage = super.isMessage();
          isMessage$Memoized = true;
        }
      }
    }
    return isMessage;
  }
}

==> truth-proto-extension-1.4.4-sources.jar: com/google/common/truth/extensions/proto/AutoValue_DiffResult_RepeatedField_PairResult.java <==
package com.google.common.truth.extensions.proto;

import com.google.common.base.Optional;
import com.google.errorprone.annotations.concurrent.LazyInit;
import com.google.protobuf.Descriptors;
import com.google.protobuf.TextFormat;
import java.lang.Integer;
import java.lang.Iterable;
import java.lang.Object;
import java.lang.Override;
import java.lang.SuppressWarnings;

final class AutoValue_DiffResult_RepeatedField_PairResult extends $AutoValue_DiffResult_RepeatedField_PairResult {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile Iterable<? extends RecursableDiffEntity> childEntities;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile boolean isMessage;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile boolean isMessage$Memoized;

  AutoValue_DiffResult_RepeatedField_PairResult(TextFormat.Printer protoPrinter,
      RecursableDiffEntity.WithResultCode.Result result,
      Descriptors.FieldDescriptor fieldDescriptor, Optional<Integer> actualFieldIndex,
      Optional<Integer> expectedFieldIndex, Optional<Object> actual, Optional<Object> expected,
      Optional<DiffResult> breakdown) {
    super(protoPrinter, result, fieldDescriptor, actualFieldIndex, expectedFieldIndex, actual, expected, breakdown);
  }

  @Override
  Iterable<? extends RecursableDiffEntity> childEntities() {
    if (childEntities == null) {
      synchronized (this) {
        if (childEntities == null) {
          childEntities = super.childEntities();
          if (childEntities == null) {
            throw new NullPointerException("childEntities() cannot return null");
          }
        }
      }
    }
    return childEntities;
  }

  @Override
  boolean isMessage() {
    if (!isMessage$Memoized) {
      synchronized (this) {
        if (!isMessage$Memoized) {
          isMessage = super.isMessage();
          isMessage$Memoized = true;
        }
      }
    }
    return isMessage;
  }
}
